@@ -101,6 +101,7 @@ typedef enum
   THUNAR_COLUMN_DATE_ACCESSED,
   THUNAR_COLUMN_DATE_MODIFIED,
   THUNAR_COLUMN_DATE_DELETED,
+  THUNAR_COLUMN_RECENCY,
   THUNAR_COLUMN_GROUP,
   THUNAR_COLUMN_MIME_TYPE,
   THUNAR_COLUMN_NAME,
@@ -251,6 +252,9 @@ typedef enum
 
 GType               thunar_zoom_level_get_type            (void)                       G_GNUC_CONST;
 ThunarThumbnailSize thunar_zoom_level_to_thumbnail_size   (ThunarZoomLevel zoom_level) G_GNUC_CONST;
+const gchar*        thunar_zoom_level_string_from_value   (ThunarZoomLevel zoom_level);
+gboolean            thunar_zoom_level_value_from_string   (const gchar    *value_string,
+                                                           gint           *value);
 
 
 #define THUNAR_TYPE_JOB_RESPONSE (thunar_job_response_get_type ())
@@ -322,6 +326,21 @@ typedef enum /*< flags >*/
 
 GType thunar_file_mode_get_type (void) G_GNUC_CONST;
 
+
+
+/**
+ * ThunarNewTabBehavior:
+ * @THUNAR_NEW_TAB_BEHAVIOR_FOLLOW_PREFERENCE   : switching to the new tab or not is controlled by a preference.
+ * @THUNAR_NEW_TAB_BEHAVIOR_SWITCH              : switch to the new tab.
+ * @THUNAR_NEW_TAB_BEHAVIOR_STAY                : stay at the current tab.
+ **/
+typedef enum
+{
+    THUNAR_NEW_TAB_BEHAVIOR_FOLLOW_PREFERENCE,
+    THUNAR_NEW_TAB_BEHAVIOR_SWITCH,
+    THUNAR_NEW_TAB_BEHAVIOR_STAY
+} ThunarNewTabBehavior;
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_ENUM_TYPES_H__ */
