@@ -53,6 +53,11 @@ enum
   PROP_DEFAULT_VIEW,
   PROP_HIDDEN_DEVICES,
   PROP_HIDDEN_BOOKMARKS,
+  PROP_LAST_RESTORE_TABS,
+  PROP_LAST_TABS_LEFT,
+  PROP_LAST_TABS_RIGHT,
+  PROP_LAST_FOCUSED_TAB_LEFT,
+  PROP_LAST_FOCUSED_TAB_RIGHT,
   PROP_LAST_COMPACT_VIEW_ZOOM_LEVEL,
   PROP_LAST_DETAILS_VIEW_COLUMN_ORDER,
   PROP_LAST_DETAILS_VIEW_COLUMN_WIDTHS,
@@ -63,6 +68,7 @@ enum
   PROP_LAST_LOCATION_BAR,
   PROP_LAST_MENUBAR_VISIBLE,
   PROP_LAST_SEPARATOR_POSITION,
+  PROP_LAST_SPLITVIEW_SEPARATOR_POSITION,
   PROP_LAST_SHOW_HIDDEN,
   PROP_LAST_SIDE_PANE,
   PROP_LAST_SORT_COLUMN,
@@ -207,6 +213,68 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                           G_TYPE_STRV,
                           EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:last-restore-tabs:
+   *
+   * %TRUE to restore the tabs as they were before closing Thunar.
+   **/
+  preferences_props[PROP_LAST_RESTORE_TABS] =
+      g_param_spec_boolean ("last-restore-tabs",
+                            "LastRestoreTabs",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:last-tabs-left:
+   *
+   * List of URI's that are used to reopen tabs on restart. There is one URI for each tab/folder that was open at the time
+   * of the last program exit. This preference holds the tabs of the default view (or the left split-view).
+   **/
+  preferences_props[PROP_LAST_TABS_LEFT] =
+      g_param_spec_boxed ("last-tabs-left",
+                          NULL,
+                          NULL,
+                          G_TYPE_STRV,
+                          EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:last-tabs-right:
+   *
+   * List of URI's that are used to reopen tabs on restart. There is one URI for each tab/folder that was open at the time
+   * of the last program exit. This preference holds the tabs of the right split-view.
+   **/
+  preferences_props[PROP_LAST_TABS_RIGHT] =
+        g_param_spec_boxed ("last-tabs-right",
+                            NULL,
+                            NULL,
+                            G_TYPE_STRV,
+                            EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:last-focused-tab-left:
+   *
+   * The index (starting from 0) of the last focused tab in left split-view
+   **/
+  preferences_props[PROP_LAST_FOCUSED_TAB_LEFT] =
+      g_param_spec_int ("last-focused-tab-left",
+                         "LastFocusedTabLeft",
+                         NULL,
+                         0, G_MAXINT, 0,
+                         EXO_PARAM_READWRITE);
+
+  /**
+   * ThunarPreferences:last-focused-tab-right:
+   *
+   * The index (starting from 0) of the last focused tab in right split-view
+   **/
+  preferences_props[PROP_LAST_FOCUSED_TAB_RIGHT] =
+      g_param_spec_int ("last-focused-tab-right",
+                         "LastFocusedTabRight",
+                         NULL,
+                         0, G_MAXINT, 0,
+                         EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:last-compact-view-zoom-level:
    *
@@ -337,6 +405,19 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                         0, G_MAXINT, 170,
                         EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:last-splitview-separator-position:
+   *
+   * The last position of the gutter in the main window,
+   * which separates the notebooks in split-view.
+   **/
+  preferences_props[PROP_LAST_SPLITVIEW_SEPARATOR_POSITION] =
+      g_param_spec_int ("last-splitview-separator-position",
+                        "LastSplitviewSeparatorPosition",
+                        NULL,
+                        0, G_MAXINT, 0,
+                        EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:last-show-hidden:
    *
