@@ -168,10 +168,12 @@ static void
 thunar_transfer_job_init (ThunarTransferJob *job)
 {
   job->preferences = thunar_preferences_get ();
-  exo_binding_new (G_OBJECT (job->preferences), "misc-file-size-binary",
-                   G_OBJECT (job), "file-size-binary");
-  exo_binding_new (G_OBJECT (job->preferences), "misc-parallel-copy-mode",
-                   G_OBJECT (job), "parallel-copy-mode");
+  g_object_bind_property (job->preferences, "misc-file-size-binary",
+                          job,              "file-size-binary",
+                          G_BINDING_SYNC_CREATE);
+  g_object_bind_property (job->preferences, "misc-parallel-copy-mode",
+                          job,              "parallel-copy-mode",
+                          G_BINDING_SYNC_CREATE);
 
   job->type = 0;
   job->source_node_list = NULL;
@@ -409,10 +411,11 @@ ttj_copy_file (ThunarTransferJob *job,
                gboolean           merge_directories,
                GError           **error)
 {
-  GFileType source_type;
-  GFileType target_type;
-  gboolean  target_exists;
-  GError   *err = NULL;
+  GFileInfo *info;
+  GFileType  source_type;
+  GFileType  target_type;
+  gboolean   target_exists;
+  GError    *err = NULL;
 
   _thunar_return_val_if_fail (THUNAR_IS_TRANSFER_JOB (job), FALSE);
   _thunar_return_val_if_fail (G_IS_FILE (source_file), FALSE);
@@ -456,6 +459,26 @@ ttj_copy_file (ThunarTransferJob *job,
                exo_job_get_cancellable (EXO_JOB (job)),
                thunar_transfer_job_progress, job, &err);
 
+  /**
+   * MR !127 notes:
+   * (Discusssion: https://gitlab.xfce.org/xfce/thunar/-/merge_requests/127)
+   *
+   * Proper solution for copying lost metadata requires
+   * `g_file_build_attribute_list_for_copy`, which is
+   * added in Glib 2.68 (which is too recent a version
+   * to add for now) so we leave a comment here. Patch
+   * this when 2.68 is ready.
+   **/
+  if (G_UNLIKELY (err == NULL && !g_file_is_native (source_file)))
+    {
+      info = g_file_query_info (source_file, G_FILE_ATTRIBUTE_TIME_MODIFIED, G_FILE_QUERY_INFO_NONE,
+                                exo_job_get_cancellable (EXO_JOB (job)), &err);
+
+      g_file_set_attributes_from_info (target_file, info, G_FILE_QUERY_INFO_NONE,
+                                       exo_job_get_cancellable (EXO_JOB (job)), &err);
+      g_clear_object (&info);
+    }
+
   /* check if there were errors */
   if (G_UNLIKELY (err != NULL && err->domain == G_IO_ERROR))
     {
@@ -690,6 +713,7 @@ thunar_transfer_job_copy_node (ThunarTransferJob  *job,
   GError               *err = NULL;
   GFile                *real_target_file = NULL;
   gchar                *base_name;
+  gboolean              should_use_copy_name;
 
   _thunar_return_if_fail (THUNAR_IS_TRANSFER_JOB (job));
   _thunar_return_if_fail (node != NULL && G_IS_FILE (node->source_file));
@@ -707,10 +731,37 @@ thunar_transfer_job_copy_node (ThunarTransferJob  *job,
   thumbnail_cache = thunar_application_get_thumbnail_cache (application);
   g_object_unref (application);
 
+  should_use_copy_name = G_UNLIKELY (!g_file_is_native (node->source_file));
+
   for (; err == NULL && node != NULL; node = node->next)
     {
+      /* query file info */
+      info = g_file_query_info (node->source_file,
+                                G_FILE_ATTRIBUTE_STANDARD_COPY_NAME "," G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                                G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+                                exo_job_get_cancellable (EXO_JOB (job)),
+                                &err);
+
+      /* abort on error or cancellation */
+      if (info == NULL)
+        break;
+
       /* guess the target file for this node (unless already provided) */
-      if (G_LIKELY (target_file == NULL))
+      if (should_use_copy_name)
+        {
+          if (target_parent_file == NULL)
+            target_parent_file = g_file_get_parent (target_file);
+          else
+            g_object_ref (target_parent_file);
+          base_name = g_strdup (g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_COPY_NAME));
+          /* copy name is NULLable, so use display name for fallback */
+          if (base_name == NULL)
+            base_name = g_strdup (g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME));
+          target_file = g_file_get_child (target_parent_file, base_name);
+          g_free (base_name);
+          g_object_unref (target_parent_file);
+        }
+      else if (G_LIKELY (target_file == NULL))
         {
           base_name = g_file_get_basename (node->source_file);
           target_file = g_file_get_child (target_parent_file, base_name);
@@ -719,20 +770,6 @@ thunar_transfer_job_copy_node (ThunarTransferJob  *job,
       else
         target_file = g_object_ref (target_file);
 
-      /* query file info */
-      info = g_file_query_info (node->source_file,
-                                G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
-                                G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-                                exo_job_get_cancellable (EXO_JOB (job)),
-                                &err);
-
-      /* abort on error or cancellation */
-      if (info == NULL)
-        {
-          g_object_unref (target_file);
-          break;
-        }
-
       /* update progress information */
       exo_job_info_message (EXO_JOB (job), "%s", g_file_info_get_display_name (info));
 
@@ -1166,30 +1203,6 @@ thunar_transfer_job_move_file (ExoJob                *job,
 }
 
 
-static GList *
-thunar_transfer_job_filter_running_jobs (GList     *jobs,
-                                         ThunarJob *own_job)
-{
-  ThunarJob *job;
-  GList     *run_jobs = NULL;
-
-  _thunar_return_val_if_fail (THUNAR_IS_TRANSFER_JOB (own_job), NULL);
-
-  for (GList *ljobs = jobs; ljobs != NULL; ljobs = ljobs->next)
-    {
-      job = ljobs->data;
-      if (job == own_job)
-        continue;
-      if (!exo_job_is_cancelled (EXO_JOB (job)) && !thunar_job_is_paused (job) && !thunar_job_is_frozen (job))
-        {
-          run_jobs = g_list_append (run_jobs, job);
-        }
-    }
-
-  return run_jobs;
-}
-
-
 
 static gboolean
 thunar_transfer_job_device_id_in_job_list (const char *device_fs_id,
@@ -1400,28 +1413,25 @@ thunar_transfer_job_determine_copy_behavior (ThunarTransferJob *transfer_job,
 
 
 /**
- * thunar_transfer_job_freeze_optional:
- * @job : a #ThunarTransferJob.
+ * thunar_transfer_job_can_start:
  *
- * Based on thunar setting, will block until all running jobs
- * doing IO on the source files or target files devices are completed.
- * The unblocking could be forced by the user in the UI.
  *
  **/
-static void
-thunar_transfer_job_freeze_optional (ThunarTransferJob *transfer_job)
+gboolean
+thunar_transfer_job_can_start (ThunarTransferJob *transfer_job,
+                               GList             *running_job_list)
 {
-  gboolean            freeze_if_src_busy;
-  gboolean            freeze_if_tgt_busy;
-  gboolean            always_parallel_copy;
-  gboolean            should_freeze_on_any_other_job;
-  gboolean            been_frozen;
+  gboolean freeze_if_src_busy;
+  gboolean freeze_if_tgt_busy;
+  gboolean always_parallel_copy;
+  gboolean should_freeze_on_any_other_job;
 
-  _thunar_return_if_fail (THUNAR_IS_TRANSFER_JOB (transfer_job));
+  _thunar_return_val_if_fail (THUNAR_IS_TRANSFER_JOB (transfer_job), FALSE);
+  _thunar_return_val_if_fail (!exo_job_is_cancelled (EXO_JOB (transfer_job)), TRUE);
 
   /* no source node list nor target file list */
   if (transfer_job->source_node_list == NULL || transfer_job->target_file_list == NULL)
-    return;
+    return TRUE;
   /* first source file */
   thunar_transfer_job_fill_source_device_info (transfer_job, ((ThunarTransferNode*) transfer_job->source_node_list->data)->source_file);
   /* first target file */
@@ -1431,46 +1441,15 @@ thunar_transfer_job_freeze_optional (ThunarTransferJob *transfer_job)
                                                &freeze_if_tgt_busy,
                                                &always_parallel_copy,
                                                &should_freeze_on_any_other_job);
-  if (always_parallel_copy)
-    return;
 
-  been_frozen = FALSE; /* this boolean can only take the TRUE value once. */
-  while (TRUE)
-    {
-      GList *jobs = thunar_job_ask_jobs (THUNAR_JOB (transfer_job));
-      GList *other_jobs = thunar_transfer_job_filter_running_jobs (jobs, THUNAR_JOB (transfer_job));
-      g_list_free (g_steal_pointer (&jobs));
-      if
-        (
-          /* should freeze because another job is running */
-          (should_freeze_on_any_other_job && other_jobs != NULL) ||
-          /* should freeze because source is busy and source device id appears in another job */
-          (freeze_if_src_busy && thunar_transfer_job_device_id_in_job_list (transfer_job->source_device_fs_id, other_jobs)) ||
-          /* should freeze because target is busy and target device id appears in another job */
-          (freeze_if_tgt_busy && thunar_transfer_job_device_id_in_job_list (transfer_job->target_device_fs_id, other_jobs))
-        )
-        g_list_free (g_steal_pointer (&other_jobs));
-      else
-        {
-          g_list_free (g_steal_pointer (&other_jobs));
-          break;
-        }
-      if (exo_job_is_cancelled (EXO_JOB (transfer_job)))
-        break;
-      if (!thunar_job_is_frozen (THUNAR_JOB (transfer_job)))
-        {
-          if (been_frozen)
-            break; /* cannot re-freeze. It means that the user force to unfreeze */
-          else
-            {
-              been_frozen = TRUE; /* first time here. The job needs to change to frozen state */
-              thunar_job_freeze (THUNAR_JOB (transfer_job));
-            }
-        }
-      g_usleep(500 * 1000); /* pause for 500ms */
-    }
-  if (thunar_job_is_frozen (THUNAR_JOB (transfer_job)))
-    thunar_job_unfreeze (THUNAR_JOB (transfer_job));
+  if (should_freeze_on_any_other_job && running_job_list != NULL)
+    return FALSE;
+  if (freeze_if_src_busy && thunar_transfer_job_device_id_in_job_list (transfer_job->source_device_fs_id, running_job_list))
+    return FALSE;
+  if (freeze_if_tgt_busy && thunar_transfer_job_device_id_in_job_list (transfer_job->target_device_fs_id, running_job_list))
+    return FALSE;
+
+  return TRUE;
 }
 
 
@@ -1574,8 +1553,6 @@ thunar_transfer_job_execute (ExoJob  *job,
             }
         }
 
-      thunar_transfer_job_freeze_optional (transfer_job);
-
       /* transfer starts now */
       transfer_job->start_time = g_get_real_time ();
 
