@@ -56,6 +56,7 @@
 
 #include <thunar/thunar-private.h>
 #include <thunar/thunar-util.h>
+#include <thunar/thunar-folder.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -646,8 +647,77 @@ thunar_util_change_working_directory (const gchar *new_directory)
   return old_directory;
 }
 
+
+
 void
 thunar_setup_display_cb (gpointer data)
 {
   g_setenv ("DISPLAY", (char *) data, TRUE);
 }
+
+
+/**
+ * thunar_util_next_new_file_name
+ * @dir : the directory to search for a free filename
+ * @file_name : the filename which will be used as the basis/default
+ *
+ * Returns a filename that is like @file_name with the possible addition of
+ * a number to differentiate it from other similarly named files. In other words
+ * it searches @dir for incrementally named files starting from @file_name
+ * and returns the first available increment.
+ *
+ * e.g. in a folder with the following files:
+ * - file
+ * - empty
+ * - file_copy
+ *
+ * Calling this functions with the above folder and @file_name equal to 'file' the returned
+ * filename will be 'file 1'.
+ *
+ * The caller is responsible to free the returned string using g_free() when no longer needed.
+ *
+ * Return value: pointer to the new filename.
+**/
+gchar*
+thunar_util_next_new_file_name (ThunarFile   *dir,
+                                const gchar  *file_name)
+{
+  ThunarFolder   *folder          = thunar_folder_get_for_file (dir);
+  unsigned long   file_name_size  = strlen (file_name);
+  unsigned        count           = 0;
+  gboolean        found_duplicate = FALSE;
+  gchar          *extension       = NULL;
+  gchar          *new_name        = g_strdup (file_name);
+
+  /* get file extension if file is not a directory */
+  extension = thunar_util_str_get_extension (file_name);
+
+  /* if the file has an extension don't include it in the search */
+  if (extension != NULL)
+    file_name_size -= strlen (extension);
+
+  /* loop through the directory until new_name is unique */
+  while (TRUE)
+    {
+      found_duplicate = FALSE;
+      for (GList *files = thunar_folder_get_files (folder); files != NULL; files = files->next)
+        {
+          ThunarFile  *file = files->data;
+          const gchar *name = thunar_file_get_display_name (file);
+
+          if (strcmp (new_name, name) == 0)
+            {
+              found_duplicate = TRUE;
+              break;
+            }
+        }
+
+      if (!found_duplicate)
+        break;
+      g_free (new_name);
+      new_name = g_strdup_printf (_("%.*s %u%s"), (int) file_name_size, file_name, ++count, extension ? extension : "");
+    }
+  g_object_unref (G_OBJECT (folder));
+
+  return new_name;
+}
